Skip to contents

A pass-through validator that accepts any field types without validation. Use it as a placeholder when you need no check on the field types.

Usage

validator_field_types_blank(db_field_types)

Arguments

db_field_types

A named character vector of database field types.

Value

Always returns TRUE.

See also

The introduction vignette, vignette("csdb", package = "csdb"), which passes this to DBTable_v9$new() as its validator_field_types argument. DBTable_v9 calls the field type validator once, while the object is being created.

Other field type validators: validator_field_types_csfmt_rts_data_v1(), validator_field_types_csfmt_rts_data_v2()

Examples

# This validator always returns TRUE regardless of input
field_types <- c("id" = "INTEGER", "name" = "TEXT", "date" = "DATE")
validator_field_types_blank(field_types)
#> [1] TRUE

# Works with any field types
other_types <- c("value" = "DOUBLE", "status" = "BOOLEAN")
validator_field_types_blank(other_types)
#> [1] TRUE